==> sirji-messages-0.0.1.tar.gz: sirji-messages-0.0.1/sirji_messages/system_prompts/agents/planner.py <==
import textwrap

from sirji_messages import AgentEnum

from .base import AgentSystemPromptBase


class PlannerSystemPrompt(AgentSystemPromptBase):

    def name(self):
        return AgentEnum.PLANNER.full_name

    def short_name(self):
        return AgentEnum.PLANNER.name

    def intro(self):
        return textwrap.dedent(f"""
          You are a {self.name()} ({self.short_name()}), helping generate a list of non-technical steps required to solve the given problem statement (PS).
          """)

    def responsibilities(self):
        return textwrap.dedent(f"""
          - Pay close attention to PS while generating non-technical steps to solve the problem programmatically.
          - Use Python, if the programming language cannot be inferred from PS.
          - Don't explain the steps further using sub-steps.
          - Generate concise steps enough to solve the problem statement.
          - Ensure that all the steps should be about either create file or install package or execute command or execute code to debug or git clone or read files.
          - Always add a step to execute the code and evaluate the response output. If the response has errors, solve them before moving ahead.                   
          - Focus on particular data points given in the PS and not solve the problem in a over-generalized manner.
          """)

    def capabilities(self):
        return textwrap.dedent("""
          - Generate non-technical steps to solve the problem programmatically.
          """)

    def ending_prompt(self):
        return ""

==> sirji-messages-0.0.7.tar.gz: sirji-messages-0.0.7/sirji_messages/system_prompts/agents/planner.py <==
import textwrap

from sirji_messages import AgentEnum

from .base import AgentSystemPromptBase


class PlannerSystemPrompt(AgentSystemPromptBase):

    def name(self):
        return AgentEnum.PLANNER.full_name

    def short_name(self):
        return AgentEnum.PLANNER.name

    def intro(self):
        return textwrap.dedent(f"""
          You are a {self.name()} ({self.short_name()}), helping generate a list of non-technical steps required to solve the given problem statement (PS).
          """)

    def responsibilities(self):
        return textwrap.dedent(f"""
          - Pay close attention to PS while generating non-technical steps to solve the problem programmatically.
          - Use Python, if the programming language cannot be inferred from PS.
          - Ensure that each step in the list of steps should start with 'Step #: ....'                    
          - Don't explain the steps further using sub-steps.
          - Generate concise steps enough to solve the problem statement.
          - Ensure that all the steps are about either create file or install package or execute command or execute code to debug or git clone or read single file or read all files in a directory (including those in its subdirectories).
          - Always add a step to execute the code and evaluate the response output. If the response has errors, solve them before moving ahead.                   
          - Focus on particular data points given in the PS and not solve the problem in an over-generalized manner.
          """)

    def capabilities(self):
        return textwrap.dedent("""
          - Generate non-technical steps to solve the problem programmatically.
          """)

    def ending_prompt(self):
        return ""
